==> v11.1.0.tar.gz: brewman/brewman/brewman/db/base.py <==
# Import all the models, so that Base has them before being
# imported by Alembic
from ..models.account import Account  # noqa: F401
from ..models.account_base import AccountBase  # noqa: F401
from ..models.account_type import AccountType  # noqa: F401
from ..models.attendance import Attendance  # noqa: F401
from ..models.batch import Batch  # noqa: F401
from ..models.client import Client  # noqa: F401
from ..models.closing_stock import ClosingStock  # noqa: F401
from ..models.cost_centre import CostCentre  # noqa: F401
from ..models.db_image import DbImage  # noqa: F401
from ..models.db_setting import DbSetting  # noqa: F401
from ..models.employee import Employee  # noqa: F401
from ..models.employee_benefit import EmployeeBenefit  # noqa: F401
from ..models.fingerprint import Fingerprint  # noqa: F401
from ..models.incentive import Incentive  # noqa: F401
from ..models.inventory import Inventory  # noqa: F401
from ..models.journal import Journal  # noqa: F401
from ..models.login_history import LoginHistory  # noqa: F401
from ..models.period import Period  # noqa: F401
from ..models.permission import Permission  # noqa: F401
from ..models.product import Product  # noqa: F401
from ..models.product_group import ProductGroup  # noqa: F401
from ..models.rate_contract import RateContract  # noqa: F401
from ..models.rate_contract_item import RateContractItem  # noqa: F401
from ..models.recipe import Recipe  # noqa: F401
from ..models.recipe_item import RecipeItem  # noqa: F401
from ..models.role import Role  # noqa: F401
from ..models.role_permission import role_permission  # noqa: F401
from ..models.stock_keeping_unit import StockKeepingUnit  # noqa: F401
from ..models.user import User  # noqa: F401
from ..models.user_role import user_role  # noqa: F401
from ..models.voucher import Voucher  # noqa: F401
from ..models.voucher_type import VoucherType  # noqa: F401
from .base_class import Base  # noqa: F401

==> v11.1.2.tar.gz: brewman/brewman/brewman/db/base.py <==
# Import all the models, so that Base has them before being
# imported by Alembic
from ..models.account import Account  # noqa: F401
from ..models.account_base import AccountBase  # noqa: F401
from ..models.account_type import AccountType  # noqa: F401
from ..models.attendance import Attendance  # noqa: F401
from ..models.batch import Batch  # noqa: F401
from ..models.client import Client  # noqa: F401
from ..models.closing_stock import ClosingStock  # noqa: F401
from ..models.cost_centre import CostCentre  # noqa: F401
from ..models.db_image import DbImage  # noqa: F401
from ..models.db_setting import DbSetting  # noqa: F401
from ..models.employee import Employee  # noqa: F401
from ..models.employee_benefit import EmployeeBenefit  # noqa: F401
from ..models.fingerprint import Fingerprint  # noqa: F401
from ..models.incentive import Incentive  # noqa: F401
from ..models.inventory import Inventory  # noqa: F401
from ..models.journal import Journal  # noqa: F401
from ..models.login_history import LoginHistory  # noqa: F401
from ..models.period import Period  # noqa: F401
from ..models.permission import Permission  # noqa: F401
from ..models.product import Product  # noqa: F401
from ..models.product_group import ProductGroup  # noqa: F401
from ..models.rate_contract import RateContract  # noqa: F401
from ..models.rate_contract_item import RateContractItem  # noqa: F401
from ..models.recipe import Recipe  # noqa: F401
from ..models.recipe_item import RecipeItem  # noqa: F401
from ..models.recipe_tag import RecipeTag  # noqa: F401
from ..models.recipe_template import RecipeTemplate  # noqa: F401
from ..models.role import Role  # noqa: F401
from ..models.role_permission import RolePermission  # noqa: F401
from ..models.stock_keeping_unit import StockKeepingUnit  # noqa: F401
from ..models.tag import Tag  # noqa: F401
from ..models.user import User  # noqa: F401
from ..models.user_role import UserRole  # noqa: F401
from ..models.voucher import Voucher  # noqa: F401
from ..models.voucher_type import VoucherType  # noqa: F401
from .base_class import reg  # noqa: F401
